@@ -265,6 +265,8 @@ class LinearExpression(Dataset):
         # support numpy arrays and convert them to dataarrays
         ds_list = []
         for (c, v) in tuples:
+            if isinstance(v, variables.ScalarVariable):
+                v = v.label
             v = as_dataarray(v)
 
             if isinstance(c, np.ndarray) or _pd_series_wo_index_name(c):
@@ -402,6 +404,9 @@ class LinearExpression(Dataset):
         -------
         Grouped linear expression.
         """
+        if isinstance(group, pd.Series):
+            logger.info("Converting group pandas.Series to xarray.DataArray")
+            group = group.to_xarray()
         groups = xr.Dataset.groupby(self, group)
 
         def func(ds):
@@ -642,7 +647,7 @@ class ScalarLinearExpression:
 
     def __sub__(self, other):
         if isinstance(other, variables.ScalarVariable):
-            other = other.to_linexpr(1)
+            other = other.to_scalar_linexpr(1)
         elif not isinstance(other, ScalarLinearExpression):
             raise TypeError(
                 "unsupported operand type(s) for -: " f"{type(self)} and {type(other)}"
@@ -692,3 +697,8 @@ class ScalarLinearExpression:
             )
 
         return constraints.AnonymousScalarConstraint(self, "=", other)
+
+    def to_linexpr(self):
+        coeffs = xr.DataArray(list(self.coeffs), dims="_term")
+        vars = xr.DataArray(list(self.vars), dims="_term")
+        return LinearExpression({"coeffs": coeffs, "vars": vars})
