@@ -210,6 +210,15 @@ class Variable(DataArray):
                 "unsupported operand type(s) for -: " f"{type(self)} and {type(other)}"
             )
 
+    def __le__(self, other):
+        return self.to_linexpr().__le__(other)
+
+    def __ge__(self, other):
+        return self.to_linexpr().__ge__(other)
+
+    def __eq__(self, other):
+        return self.to_linexpr().__eq__(other)
+
     def groupby_sum(self, group):
         """
         Sum variable over groups.
@@ -436,6 +445,15 @@ class Variables:
 
     _merge_inplace = _merge_inplace
 
+    def _ipython_key_completions_(self):
+        """
+        Provide method for the key-autocompletions in IPython.
+
+        See http://ipython.readthedocs.io/en/stable/config/integrating.html#tab-completion
+        For the details.
+        """
+        return list(self)
+
     def add(self, name, labels: DataArray, lower: DataArray, upper: DataArray):
         """
         Add variable `name`.
@@ -616,34 +634,37 @@ class ScalarVariable:
     label: int
     coords: dict = None
 
-    def to_linexpr(self, coeff=1):
+    def to_scalar_linexpr(self, coeff=1):
         if not isinstance(coeff, (int, float)):
             raise TypeError(f"Coefficient must be a numeric value, got {type(coeff)}.")
         return expressions.ScalarLinearExpression((coeff,), (self.label,))
 
+    def to_linexpr(self, coeff=1):
+        return self.to_scalar_linexpr(coeff).to_linexpr()
+
     def __neg__(self):
-        return self.to_linexpr(-1)
+        return self.to_scalar_linexpr(-1)
 
     def __add__(self, other):
-        return self.to_linexpr(1) + other
+        return self.to_scalar_linexpr(1) + other
 
     def __sub__(self, other):
-        return self.to_linexpr(1) - other
+        return self.to_scalar_linexpr(1) - other
 
     def __mul__(self, coeff):
-        return self.to_linexpr(coeff)
+        return self.to_scalar_linexpr(coeff)
 
     def __rmul__(self, coeff):
-        return self.to_linexpr(coeff)
+        return self.to_scalar_linexpr(coeff)
 
     def __div__(self, coeff):
-        return self.to_linexpr(1 / coeff)
+        return self.to_scalar_linexpr(1 / coeff)
 
     def __le__(self, other):
-        return self.to_linexpr(1).__le__(other)
+        return self.to_scalar_linexpr(1).__le__(other)
 
     def __ge__(self, other):
-        return self.to_linexpr(1).__ge__(other)
+        return self.to_scalar_linexpr(1).__ge__(other)
 
     def __eq__(self, other):
-        return self.to_linexpr(1).__eq__(other)
+        return self.to_scalar_linexpr(1).__eq__(other)
